<?php
/**
 * @file
 * Rules module integration
 */

/**
 * Implements hook_event_info().
 */
function intel_rules_event_info() {
  $defaults = array(
    'group' => t('Intel'),
    'module' => 'intel',
  );
  return array(
    'intel_form_submission' => $defaults + array(
      'label' => t('Form submission received'),
      'variables' => array(
        'type' => array(
          'type' => 'text',
          'label' => t('Form type'),
        ),
        'fid' => array(
          'type' => 'text',
          'label' => t('Form id'),
        ),
        'visitor' => array(
          'type' => 'intel_visitor',
          'label' => t('Visitor'),
          //'save' => TRUE,
        ),
      ),
    ),
    'intel_phone_call' => $defaults + array(
      'label' => t('Phone call received'),
      'variables' => array(
        'type' => array(
          'type' => 'text',
          'label' => t('Call type'),
        ),
        'number' => array(
          'type' => 'text',
          'label' => t('Number called'),
        ),
        'visitor' => array(
          'type' => 'intel_visitor',
          'label' => t('Visitor'),
          //'save' => TRUE,
        ),
      ),
    ),
  );
}

/**
 * Implements hook_rules_condition_info().
 */
function intel_rules_condition_info() {
  return array(
    'intel_rules_condition_number_belongs_to_user' => array(
      'label' => t('Number belongs to a valid user'),
      'arguments' => array(
        'number' => array(
          'type' => 'text',
          'label' => t('Phone Number'),
        ),
      ),
      'group' => t('Intel'),
      'module' => 'intel',
    ),
  );
}

/**
 * Implements hook_rules_action_info().
 */
function intel_rules_action_info() {
  $defaults = array(
    'group' => t('Intel'),
    'module' => 'intel',
  );
  $actions['intel_send_sms_to_user'] = $defaults + array(
    'label' => t('Send an SMS to a user'),
    'base' => 'intel_rules_action_send_sms_to_user',
    'parameter' => array(
      'account' => array(
        'type' => 'user',
        'label' => t('User'),
        'save' => TRUE,
      ),
      'message' => array(
        'type' => 'text',
        'label' => t('Message'),
      ),
    ),
  );
  $actions['intel_twiml_output'] = $defaults + array(
    'label' => t('Output TwiML'),
    'base' => 'intel_rules_twiml_output',
    'parameter' => array(
      'twiml_id' => array(
        'type' => 'text',
        'label' => t('TwiML'),
        'options list' => 'intel_twiml_options_list',
        'restriction' => 'input',
      ),
    ),
  );
  $actions['intel_send_sms_to_number'] = $defaults + array(
    'label' => t('Send an SMS to a number'),
    'base' => 'intel_rules_action_send_sms_to_number',
    'parameter' => array(
      'country' => array(
        'type' => 'text',
        'label' => t('Country code'),
        'options list' => 'intel_country_codes',
      ),
      'number' => array(
        'type' => 'text',
        'label' => t('Number'),
      ),
      'message' => array(
        'type' => 'text',
        'label' => t('Message'),
      ),
    ),
  );
  return $actions;
}

/**
 * Action: Send an SMS to a user.
 */
function intel_rules_action_send_sms_to_user($account, $message) {
  if (!empty($account->intel_user['number']) && $account->intel_user['status'] == 2) {
    intel_send($account->intel_user['number'], $message, $account->intel_user['country']);
  }
}

/**
 * Action: Send an SMS to a number.
 */
function intel_rules_action_send_sms_to_number($country, $number, $message) {
  intel_send($number, $message, $country);
}

/**
 * Condition: Validate if a number belongs to a user on the site.
 */
function intel_rules_condition_number_belongs_to_user($number) {
  return intel_verify_number($number);
}

/**
 * Action: Output TwiML.
 */
function intel_rules_twiml_output($twiml_id) {
  $twiml = intel_twiml_load($twiml_id);
  echo $twiml['data'];
  exit();
}
